Prevent accidental overwrite of existing build.
diff --git a/releng/org.eclipse.rap.incubator.releng/scripts/init-functions.sh b/releng/org.eclipse.rap.incubator.releng/scripts/init-functions.sh
index 302f0ef..4994e25 100755
--- a/releng/org.eclipse.rap.incubator.releng/scripts/init-functions.sh
+++ b/releng/org.eclipse.rap.incubator.releng/scripts/init-functions.sh
@@ -24,8 +24,6 @@
     -application org.eclipse.equinox.p2.artifact.repository.mirrorApplication \
     -source ${SOURCE} \
     -destination ${DESTINATION} \
-    -destinationName ${DESTINATION_NAME} \
-    -raw \
-    -compare
+    -destinationName ${DESTINATION_NAME}
 }
diff --git a/releng/org.eclipse.rap.incubator.releng/scripts/build.sh b/releng/org.eclipse.rap.incubator.releng/scripts/build.sh
index 80c4dec..0f738de 100755
--- a/releng/org.eclipse.rap.incubator.releng/scripts/build.sh
+++ b/releng/org.eclipse.rap.incubator.releng/scripts/build.sh
@@ -85,9 +85,14 @@
 test -n "${TIMESTAMP}" || exit 1
 
 ######################################################################
 # copy repository to target location
 COMPONENT_DIRECTORY=${REPOSITORY_BASE_PATH}/${COMPONENT_NAME}
 echo "Copy new ${TIMESTAMP} repository of ${COMPONENT_NAME} to ${COMPONENT_DIRECTORY}" 
+if [ -d "${COMPONENT_DIRECTORY}" ] ; then
+  echo "Build already exists in ${COMPONENT_DIRECTORY}. Nothing to do."
+  echo "Stopping build ${TIMESTAMP} of ${COMPONENT_NAME} ${VERSION}."
+  exit 0
+fi
 mkdir -p ${COMPONENT_DIRECTORY}
 cd ${COMPONENT_DIRECTORY}
 cp -a ${REPOSITORY_DIRECTORY} ${COMPONENT_DIRECTORY}/${TIMESTAMP}
@@ -85,9 +85,14 @@
 
 ######################################################################
-# copy repository to target location
+# copy repository to target location if new version available
 COMPONENT_DIRECTORY=${REPOSITORY_BASE_PATH}/${COMPONENT_NAME}
 echo "Copy new ${TIMESTAMP} repository of ${COMPONENT_NAME} to ${COMPONENT_DIRECTORY}" 